<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="39"/>
        <source>Row</source>
        <translation>Wiersz</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="40"/>
        <source>Column</source>
        <translation>Kolumna</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="41"/>
        <source>Characters %1</source>
        <translation>Znaki %1</translation>
    </message>
</context>
<context>
    <name>DDropdownMenu</name>
    <message>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="300"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="344"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="349"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
</context>
<context>
    <name>EditWrapper</name>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="201"/>
        <location filename="../src/editor/editwrapper.cpp" line="264"/>
        <location filename="../src/editor/editwrapper.cpp" line="321"/>
        <location filename="../src/editor/editwrapper.cpp" line="536"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="316"/>
        <source>Do you want to save this file?</source>
        <translation>Czy chcesz zapisać plik?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="262"/>
        <location filename="../src/editor/editwrapper.cpp" line="319"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="259"/>
        <source>Encoding changed. Do you want to save the file now?</source>
        <translation>Kodowanie zmienione. Czy chcesz teraz zapisać plik?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="320"/>
        <source>Discard</source>
        <translation>Odrzuć</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="445"/>
        <source>You do not have permission to save %1</source>
        <translation>Nie posiadasz uprawnień do zapisania %1</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="607"/>
        <source>File removed on the disk. Save it now?</source>
        <translation>Plik został usunięty z dysku. Czy chcesz go zapisać?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="612"/>
        <source>File has changed on disk. Reload?</source>
        <translation>Plik został zmieniony na dysku. Czy chcesz go ponownie wczytać?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="634"/>
        <location filename="../src/widgets/bottombar.cpp" line="60"/>
        <source>INSERT</source>
        <translation>WSTAWIANIE</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="637"/>
        <source>OVERWRITE</source>
        <translation>NADPISYWANIE</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="640"/>
        <source>R/O</source>
        <translation>TYLKO DO ODCZYTU</translation>
    </message>
</context>
<context>
    <name>FindBar</name>
    <message>
        <location filename="../src/controls/findbar.cpp" line="40"/>
        <source>Find</source>
        <translation>Znajdź</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="44"/>
        <source>Previous</source>
        <translation>Poprzednie</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="46"/>
        <source>Next</source>
        <translation>Następne</translation>
    </message>
</context>
<context>
    <name>JumpLineBar</name>
    <message>
        <location filename="../src/controls/jumplinebar.cpp" line="40"/>
        <source>Go to Line: </source>
        <translation>Przejdź do wiersza:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="27"/>
        <source>Text Editor is a powerful tool for viewing and editing text files.</source>
        <translation>Edytor Tekstu to potężne narzędzie do przeglądania i edycji plików tekstowych.</translation>
    </message>
    <message>
        <location filename="../src/editorapplication.cpp" line="38"/>
        <source>Text Editor</source>
        <translation>Edytor tekstu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="35"/>
        <source>Text Editor</source>
        <translation>Edytor tekstu</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="203"/>
        <location filename="../src/editor/editwrapper.cpp" line="538"/>
        <location filename="../src/widgets/window.cpp" line="956"/>
        <location filename="../src/widgets/window.cpp" line="973"/>
        <location filename="../src/widgets/window.cpp" line="1064"/>
        <location filename="../src/widgets/window.cpp" line="1079"/>
        <source>Encoding</source>
        <translation>Kodowanie</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="24"/>
        <source>Basic</source>
        <translation>Podstawowe</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="25"/>
        <source>Font Style</source>
        <translation>Styl czcionki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="26"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="27"/>
        <source>Font Size</source>
        <translation>Rozmiar czcionki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="28"/>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="29"/>
        <location filename="../src/controls/settingsdialog.cpp" line="30"/>
        <source>Keymap</source>
        <translation>Mapowanie klawiszy</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="31"/>
        <location filename="../src/controls/settingsdialog.cpp" line="107"/>
        <location filename="../src/widgets/window.cpp" line="1482"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="32"/>
        <source>New tab</source>
        <translation>Nowa karta</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="33"/>
        <source>New window</source>
        <translation>Nowe okno</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="34"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="35"/>
        <source>Save as</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="36"/>
        <source>Next tab</source>
        <translation>Następna karta</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="37"/>
        <source>Previous tab</source>
        <translation>Poprzednia karta</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="38"/>
        <source>Close tab</source>
        <translation>Zamknij kartę</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="39"/>
        <source>Close other tabs</source>
        <translation>Zamknij pozostałe karty</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="40"/>
        <source>Restore tab</source>
        <translation>Przywróć kartę</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="41"/>
        <source>Open file</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="42"/>
        <source>Increment font size</source>
        <translation>Zwiększ rozmiar czcionki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="43"/>
        <source>Decrement font size</source>
        <translation>Zmniejsz rozmiar czcionki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="44"/>
        <source>Reset font size</source>
        <translation>Zresetuj rozmiar czcionki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="45"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="46"/>
        <source>Toggle fullscreen</source>
        <translation>Przełącz pełny ekran</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="47"/>
        <source>Find</source>
        <translation>Znajdź</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="48"/>
        <source>Replace</source>
        <translation>Zamień</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="49"/>
        <source>Go to line</source>
        <translation>Przejdź do wiersza</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="50"/>
        <source>Save cursor position</source>
        <translation>Zapisz pozycję kursora</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="51"/>
        <source>Reset cursor position</source>
        <translation>Zresetuj pozycję kursora</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="52"/>
        <source>Exit</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="53"/>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="54"/>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="55"/>
        <source>Editor</source>
        <translation>Edytor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="56"/>
        <source>Increase indent</source>
        <translation>Zwiększ wcięcie</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="57"/>
        <source>Decrease indent</source>
        <translation>Zmniejsz wcięcie</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="58"/>
        <source>Forward character</source>
        <translation>Znak do przodu</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="59"/>
        <source>Backward character</source>
        <translation>Znak do tyłu</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="60"/>
        <source>Forward word</source>
        <translation>Następne słowo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="61"/>
        <source>Backward word</source>
        <translation>Poprzednie słowo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="62"/>
        <source>Next line</source>
        <translation>Następny wiersz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="63"/>
        <source>Previous line</source>
        <translation>Poprzedni wiersz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="64"/>
        <source>New line</source>
        <translation>Nowy wiersz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="65"/>
        <source>New line above</source>
        <translation>Nowy wiersz powyżej</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="66"/>
        <source>New line below</source>
        <translation>Nowy wiersz poniżej</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="67"/>
        <source>Duplicate line</source>
        <translation>Duplikuj wiersz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="68"/>
        <source>Delete to end of line</source>
        <translation>Usuń do końca wiersza</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="69"/>
        <source>Delete current line</source>
        <translation>Usuń bieżący wiersz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="70"/>
        <source>Swap line up</source>
        <translation>Zamień wiersz z powyższym</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="71"/>
        <source>Swap line down</source>
        <translation>Zamień wiersz z poniższym</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="72"/>
        <source>Scroll up one line</source>
        <translation>Przewiń jeden wiersz w górę</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="73"/>
        <source>Scroll down one line</source>
        <translation>Przewiń jeden wiersz w dół</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="74"/>
        <source>Page up</source>
        <translation>Strona w górę</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="75"/>
        <source>Page down</source>
        <translation>Strona w dół</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="76"/>
        <source>Move to end of line</source>
        <translation>Przejdź do końca wiersza</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="77"/>
        <source>Move to start of line</source>
        <translation>Przejdź do początku wiersza</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="78"/>
        <source>Move to end of text</source>
        <translation>Przejdź do końca tekstu</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="79"/>
        <source>Move to start of text</source>
        <translation>Przejdź do początku tekstu</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="80"/>
        <source>Move to line indentation</source>
        <translation>Przejdź do wcięcia wiersza</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="81"/>
        <source>Upper case</source>
        <translation>Wielkie litery</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="82"/>
        <source>Lower case</source>
        <translation>Małe litery</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="83"/>
        <source>Capitalize</source>
        <translation>Wielka litera</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="84"/>
        <source>Delete backward word</source>
        <translation>Usuń poprzedzające słowo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="85"/>
        <source>Delete forward word</source>
        <translation>Usuń następujące słowo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="86"/>
        <source>Forward over a pair</source>
        <translation>Przenieś się za nawias</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="87"/>
        <source>Backward over a pair</source>
        <translation>Przenieś się przed nawias</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="88"/>
        <source>Select all</source>
        <translation>Zaznacz wszystko</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="89"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="90"/>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="91"/>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="92"/>
        <source>Transpose character</source>
        <translation>Przenieś znak</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="93"/>
        <source>Mark</source>
        <translation>Oznacz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="94"/>
        <source>Unmark</source>
        <translation>Odznacz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="95"/>
        <source>Copy line</source>
        <translation>Kopiuj wiersz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="96"/>
        <source>Cut line</source>
        <translation>Wytnij wiersz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="97"/>
        <source>Merge lines</source>
        <translation>Połącz wiersze</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="98"/>
        <source>Read-Only mode</source>
        <translation>Tryb tylko-do-odczytu</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="99"/>
        <source>Add comment</source>
        <translation>Dodaj komentarz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="100"/>
        <source>Remove comment</source>
        <translation>Usuń komentarz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="101"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="102"/>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="103"/>
        <source>Add/Remove bookmark</source>
        <translation>Dodaj/Usuń zakładkę</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="104"/>
        <source>Move to previous bookmark</source>
        <translation>Przejdź do poprzedniej zakładki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="105"/>
        <source>Move to next bookmark</source>
        <translation>Przejdź do następnej zakładki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="106"/>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="108"/>
        <source>Window size</source>
        <translation>Rozmiar okna</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="109"/>
        <source>Tab width</source>
        <translation>Szerokość zakładki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="111"/>
        <source>Word wrap</source>
        <translation>Zawijanie tekstu</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="112"/>
        <source>Code folding flag</source>
        <translation>Pokaż strzałki zawijające kod</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="113"/>
        <source>Show line numbers</source>
        <translation>Pokaż numery linii</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="114"/>
        <source>Show bookmarks icon</source>
        <translation>Pokaż ikonę zakładek</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="115"/>
        <source>Show whitespaces and tabs</source>
        <translation>Pokaż spacje i tabulatory</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="116"/>
        <source>Highlight current line</source>
        <translation>Podkreśl bieżący wiersz</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="117"/>
        <source>Color mark</source>
        <translation>Kolor oznaczenia</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="120"/>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="121"/>
        <source>WesternEuropean</source>
        <translation>Zachodnio Europejski</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="122"/>
        <source>CentralEuropean</source>
        <translation>Europa Centralna</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="123"/>
        <source>Baltic</source>
        <translation>Bałtycki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="124"/>
        <source>Cyrillic</source>
        <translation>Cyrylica</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="125"/>
        <source>Arabic</source>
        <translation>Arabski</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="130"/>
        <source>Celtic</source>
        <translation>Celtycki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="131"/>
        <source>SouthEasternEuropean</source>
        <translation>Południowo-Wschodnia Europa</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="126"/>
        <source>Greek</source>
        <translation>Grecki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="127"/>
        <source>Hebrew</source>
        <translation>Hebrajski</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="132"/>
        <source>ChineseSimplified</source>
        <translation>Chiński uproszczony</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="133"/>
        <source>ChineseTraditional</source>
        <translation>Chiński tradycyjny</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="134"/>
        <source>Japanese</source>
        <translation>Japoński</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="135"/>
        <source>Korean</source>
        <translation>Koreański</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="129"/>
        <source>Thai</source>
        <translation>Tajlandzki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="128"/>
        <source>Turkish</source>
        <translation>Turecki</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="136"/>
        <source>Vietnamese</source>
        <translation>Wietnamski</translation>
    </message>
    <message>
        <location filename="../src/startmanager.cpp" line="762"/>
        <source>File not saved</source>
        <translation>Plik nie został zapisany</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="974"/>
        <location filename="../src/widgets/window.cpp" line="1065"/>
        <location filename="../src/widgets/window.cpp" line="1080"/>
        <source>Line Endings</source>
        <translation>Zakończenia wiersza</translation>
    </message>
</context>
<context>
    <name>ReplaceBar</name>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="39"/>
        <source>Find</source>
        <translation>Znajdź</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="43"/>
        <source>Replace With</source>
        <translation>Zamień na</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="47"/>
        <source>Replace</source>
        <translation>Zastąp</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="50"/>
        <source>Skip</source>
        <translation>Pomiń</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="53"/>
        <source>Replace Rest</source>
        <translation>Zastąp pozostałe</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="56"/>
        <source>Replace All</source>
        <translation>Zastąp wszystkie</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="../third/libiconv-1.16/src/iconv.c" line="103"/>
        <source/>
        <comment>The first line of the short usage message.</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/common/settings.cpp" line="91"/>
        <source>Standard</source>
        <translation>Standardowe</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="91"/>
        <source>Customize</source>
        <translation>Dostosuj</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Normal</source>
        <translation>Normalne</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Maximum</source>
        <translation>Maksymalne</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="292"/>
        <source>This shortcut conflicts with system shortcut %1</source>
        <translation>Ten skrót jest w konflikcie ze skrótem systemowym %1</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="294"/>
        <source>This shortcut conflicts with %1, click on Replace to make this shortcut effective immediately</source>
        <translation>Ten skrót jest w konflikcie z %1, kliknij Zamień, aby skrót zaczął działać od razu</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="410"/>
        <location filename="../src/common/settings.cpp" line="418"/>
        <source>The shortcut %1 is invalid, please set another one.</source>
        <translation>Skrót %1 jest nieprawidłowy, ustaw inny.</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="445"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="446"/>
        <source>Replace</source>
        <translation>Zamień</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="448"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>StartManager</name>
    <message>
        <location filename="../src/startmanager.cpp" line="340"/>
        <source>Untitled %1</source>
        <translation>Bez tytułu %1</translation>
    </message>
</context>
<context>
    <name>Tabbar</name>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="515"/>
        <source>Close tab</source>
        <translation>Zamknij kartę</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="516"/>
        <source>Close other tabs</source>
        <translation>Zamknij pozostałe karty</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="517"/>
        <source>More options</source>
        <translation>Więcej opcji</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="518"/>
        <source>Close tabs to the left</source>
        <translation>Zamknij karty po lewej stronie</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="519"/>
        <source>Close tabs to the right</source>
        <translation>Zamknij karty po prawej stronie</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="520"/>
        <source>Close unmodified tabs</source>
        <translation>Zamknij niezmodyfikowane karty</translation>
    </message>
</context>
<context>
    <name>TextEdit</name>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="235"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="236"/>
        <source>Redo</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="237"/>
        <source>Cut</source>
        <translation>Wytnij</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="238"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="239"/>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="240"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="241"/>
        <source>Select All</source>
        <translation>Zaznacz wszystko</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="242"/>
        <location filename="../src/widgets/window.cpp" line="361"/>
        <source>Find</source>
        <translation>Znajdź</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="243"/>
        <location filename="../src/widgets/window.cpp" line="362"/>
        <source>Replace</source>
        <translation>Zamień</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="244"/>
        <source>Go to Line</source>
        <translation>Przejdź do wiersza</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="245"/>
        <source>Turn on Read-Only mode</source>
        <translation>Włącz tryb tylko-do-odczytu</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="246"/>
        <source>Turn off Read-Only mode</source>
        <translation>Wyłącz tryb tylko-do-odczytu</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="248"/>
        <source>Exit fullscreen</source>
        <translation>Wyłącz pełny ekran</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="249"/>
        <source>Display in file manager</source>
        <translation>Wyświetl w Menedżerze plików</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="250"/>
        <location filename="../src/editor/dtextedit.cpp" line="302"/>
        <source>Add Comment</source>
        <translation>Dodaj komentarz</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="251"/>
        <source>Text to Speech</source>
        <translation>Tekst na mowę</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="252"/>
        <source>Stop reading</source>
        <translation>Przestań czytać</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="253"/>
        <source>Speech to Text</source>
        <translation>Mowa na tekst</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="254"/>
        <source>Translate</source>
        <translation>Przetłumacz</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="255"/>
        <source>Column Mode</source>
        <translation>Tryb kolumnowy</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="256"/>
        <source>Add bookmark</source>
        <translation>Dodaj zakładkę</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="257"/>
        <source>Remove Bookmark</source>
        <translation>Usuń zakładkę</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="258"/>
        <source>Previous bookmark</source>
        <translation>Poprzednia zakładka</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="259"/>
        <source>Next bookmark</source>
        <translation>Następna zakładka</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="260"/>
        <source>Remove All Bookmarks</source>
        <translation>Usuń wszystkie zakładki</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="261"/>
        <source>Fold All</source>
        <translation>Zwiń wszystko</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="262"/>
        <source>Fold Current Level</source>
        <translation>Zwiń bieżący poziom</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="263"/>
        <source>Unfold All</source>
        <translation>Rozwiń wszystko</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="264"/>
        <source>Unfold Current Level</source>
        <translation>Rozwiń bieżący poziom</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="269"/>
        <source>Color Mark</source>
        <translation>Kolor oznaczenia</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="273"/>
        <source>Clear All Marks</source>
        <translation>Wyczyść wszystkie oznaczenia</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="274"/>
        <source>Clear Last Mark</source>
        <translation>Wyczyść ostatnie oznaczenie</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="283"/>
        <source>Mark</source>
        <translation>Oznacz</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="295"/>
        <source>Mark All</source>
        <translation>Oznacz wszystko</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="303"/>
        <source>Remove Comment</source>
        <translation>Usuń komentarz</translation>
    </message>
    <message>
        <source>Failed to paste text: it is too large</source>
        <translation type="vanished">Nie udało się wkleić tekstu: jest go zbyt dużo</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2581"/>
        <source>Copy failed: not enough memory</source>
        <translation>Kopiowanie nieudane: niewystarczająca ilość pamięci</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2665"/>
        <source>Press ALT and click lines to edit in column mode</source>
        <translation>Naciśnij ALT i kliknij linie, aby edytować w trybie kolumnowym</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="346"/>
        <source>Change Case</source>
        <translation>Zmień wielkość znaków</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="347"/>
        <source>Upper Case</source>
        <translation>Wielkie litery</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="348"/>
        <source>Lower Case</source>
        <translation>Małe litery</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="349"/>
        <source>Capitalize</source>
        <translation>Wielka litera</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="64"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1184"/>
        <source>Selected line(s) copied</source>
        <translation>Wybrane linie zostały skopiowane</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1190"/>
        <source>Current line copied</source>
        <translation>Bieżąca linia została skopiowana</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1210"/>
        <source>Selected line(s) clipped</source>
        <translation>Obcięto wybrane linie</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1222"/>
        <source>Current line clipped</source>
        <translation>Obcięto bieżącą linię</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2591"/>
        <source>Paste failed: not enough memory</source>
        <translation>Wklejanie nieudane: niewystarczająca ilość pamięci</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3439"/>
        <source>Read-Only mode is off</source>
        <translation>Tryb tylko-do-odczytu jest wyłączony</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3446"/>
        <location filename="../src/editor/dtextedit.cpp" line="3465"/>
        <location filename="../src/editor/dtextedit.cpp" line="6150"/>
        <source>Read-Only mode is on</source>
        <translation>Tryb tylko-do-odczytu jest włączony</translation>
    </message>
</context>
<context>
    <name>WarningNotices</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="36"/>
        <source>Reload</source>
        <translation>Przeładuj</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="38"/>
        <location filename="../src/widgets/window.cpp" line="357"/>
        <source>Save as</source>
        <translation>Zapisz jako</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="353"/>
        <source>New window</source>
        <translation>Nowe okno</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="354"/>
        <source>New tab</source>
        <translation>Nowa karta</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="355"/>
        <source>Open file</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="356"/>
        <location filename="../src/widgets/window.cpp" line="2217"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="358"/>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="359"/>
        <source>Switch theme</source>
        <translation>Przełącz motyw</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="360"/>
        <location filename="../src/widgets/window.cpp" line="1542"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="471"/>
        <location filename="../src/widgets/window.cpp" line="2468"/>
        <source>Read-Only</source>
        <translation>Tylko-do-odczytu</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="487"/>
        <source>You do not have permission to open %1</source>
        <translation>Nie posiadasz uprawnień do otwarcia %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="522"/>
        <source>Invalid file: %1</source>
        <translation>Nieprawidłowy plik: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="602"/>
        <location filename="../src/widgets/window.cpp" line="644"/>
        <source>Do you want to save this file?</source>
        <translation>Czy chcesz zapisać ten plik?</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="894"/>
        <source>You do not have permission to save %1</source>
        <translation>Nie posiadasz uprawnień do zapisania %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="918"/>
        <source>Saved successfully</source>
        <translation>Zapisano pomyślnie</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="954"/>
        <location filename="../src/widgets/window.cpp" line="1021"/>
        <location filename="../src/widgets/window.cpp" line="1062"/>
        <source>Save File</source>
        <translation>Zapisz plik</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1023"/>
        <source>Encoding</source>
        <translation>Kodowanie</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1211"/>
        <source>Read-Only mode is on</source>
        <translation>Tryb tylko-do-odczytu jest włączony</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1441"/>
        <source>Current location remembered</source>
        <translation>Aktualna lokalizacja została zapamiętana</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1492"/>
        <source>Ctrl+&apos;=&apos;</source>
        <translation>Ctrl+&apos;=&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1495"/>
        <source>Ctrl+&apos;-&apos;</source>
        <translation>Ctrl+&apos;-&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1524"/>
        <source>Editor</source>
        <translation>Edytor</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1890"/>
        <source>Untitled %1</source>
        <translation>Bez tytułu %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2215"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2216"/>
        <source>Discard</source>
        <translation>Odrzuć</translation>
    </message>
</context>
</TS>